@@ -5,8 +5,12 @@ mod lexing;
 mod media_type;
 mod parsed_source;
 mod parsing;
+#[cfg(feature = "scopes")]
+mod scopes;
 mod text_encoding;
 mod text_info;
+#[cfg(feature = "transpiling")]
+mod transpiling;
 mod types;
 
 #[cfg(feature = "view")]
@@ -17,7 +21,11 @@ pub use lexing::*;
 pub use media_type::*;
 pub use parsed_source::*;
 pub use parsing::*;
+#[cfg(feature = "scopes")]
+pub use scopes::*;
 pub use text_info::*;
+#[cfg(feature = "transpiling")]
+pub use transpiling::*;
 pub use types::*;
 
 pub mod swc {
