@@ -178,6 +178,21 @@ impl SourceTextInfo {
     )
   }
 
+  /// Gets the byte position of the provided line and column index.
+  ///
+  /// Note that this will panic if providing a line index outside the
+  /// bounds of the number of lines, but will clip the the line end byte index
+  /// when exceeding the line length.
+  pub fn byte_index(
+    &self,
+    line_and_column_index: LineAndColumnIndex,
+  ) -> BytePos {
+    self.assert_line_index(line_and_column_index.line_index);
+    self.get_pos_from_relative_index(
+      self.text_lines.byte_index(line_and_column_index),
+    )
+  }
+
   /// Gets a reference to the text slice of the line at the provided
   /// 0-based index.
   ///
@@ -189,7 +204,7 @@ impl SourceTextInfo {
     &self.text_str()[line_start..line_end]
   }
 
-  /// Gets the source text located within the specified span.
+  /// Gets the source text located within the provided span.
   pub fn span_text(&self, span: &Span) -> &str {
     let offset_lo = (span.lo() - self.start_pos).0 as usize;
     let offset_hi = (span.hi - self.start_pos).0 as usize;
@@ -216,7 +231,7 @@ impl SourceTextInfo {
   fn assert_line_index(&self, line_index: usize) {
     if line_index >= self.lines_count() {
       panic!(
-        "The specified line index {} was greater or equal to the number of lines of {}.",
+        "The provided line index {} was greater or equal to the number of lines of {}.",
         line_index,
         self.lines_count()
       );
@@ -333,6 +348,56 @@ mod test {
     info.line_and_column_index(BytePos(6));
   }
 
+  #[test]
+  fn byte_index() {
+    let text = "12\n3\r\nβ\n5";
+    for i in 0..10 {
+      let source_file =
+        SourceTextInfo::new_with_pos(BytePos(i), Arc::new(text.to_string()));
+      assert_byte_index(&source_file, 0, 0, i); // 1
+      assert_byte_index(&source_file, 0, 1, 1 + i); // 2
+      assert_byte_index(&source_file, 0, 2, 2 + i); // \n
+      assert_byte_index(&source_file, 0, 3, 2 + i); // beyond newline
+      assert_byte_index(&source_file, 0, 4, 2 + i); // beyond newline
+      assert_byte_index(&source_file, 1, 0, 3 + i); // 3
+      assert_byte_index(&source_file, 1, 1, 4 + i); // \r
+      assert_byte_index(&source_file, 1, 2, 4 + i); // \n
+      assert_byte_index(&source_file, 2, 0, 6 + i); // β
+      assert_byte_index(&source_file, 2, 1, 8 + i); // \n
+      assert_byte_index(&source_file, 3, 0, 9 + i); // 5
+      assert_byte_index(&source_file, 3, 1, 10 + i); // <EOF>
+      assert_byte_index(&source_file, 3, 2, 10 + i); // beyond <EOF>
+    }
+  }
+
+  fn assert_byte_index(
+    source_file: &SourceTextInfo,
+    line_index: usize,
+    column_index: usize,
+    pos: u32,
+  ) {
+    assert_eq!(
+      source_file.byte_index(LineAndColumnIndex {
+        line_index,
+        column_index,
+      }),
+      BytePos(pos)
+    );
+  }
+
+  #[test]
+  #[should_panic(
+    expected = "The provided line index 1 was greater or equal to the number of lines of 1."
+  )]
+  fn byte_index_panic_greater_than_lines() {
+    let info =
+      SourceTextInfo::new_with_pos(BytePos(1), Arc::new("test".to_string()));
+    info.byte_index(LineAndColumnIndex {
+      line_index: 1,
+      column_index: 0,
+    });
+  }
+
   #[test]
   fn line_start() {
     let text = "12\n3\r\n4\n5";
@@ -356,7 +421,7 @@ mod test {
 
   #[test]
   #[should_panic(
-    expected = "The specified line index 1 was greater or equal to the number of lines of 1."
+    expected = "The provided line index 1 was greater or equal to the number of lines of 1."
   )]
   fn line_start_equal_number_lines() {
     let info =
@@ -387,7 +452,7 @@ mod test {
 
   #[test]
   #[should_panic(
-    expected = "The specified line index 1 was greater or equal to the number of lines of 1."
+    expected = "The provided line index 1 was greater or equal to the number of lines of 1."
   )]
   fn line_end_equal_number_lines() {
     let info =
